<?php

namespace Modules\OperadorLogistico\Services;

use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;
use \Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use \Zeedhi\Framework\DB\StoredProcedure\Param;

class ConsolidacaoOLService {
    
    protected $connection;
    
    public function __construct($entityManager, $environment){
        $this->connection = $entityManager->getConnection();
        $this->environment = $environment;
    }
    
    public function updateItemSolCons($row){
		$param = array();
        $param['P_NRSEQUCONSOL'] = $row[0]['NRSEQUCONSOL'];
        $query = "UPDATE ITEMSOLI SET NRSEQUCONSOL = NULL WHERE NRSEQUCONSOL = :P_NRSEQUCONSOL";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($param);
        } catch (Exception $e){
            throw $e;
        }
    }
    
    public function deleteConsSolOL($row){
    	$param = array();
        $param['P_NRSEQUCONSOL'] = $row[0]['NRSEQUCONSOL'];
    	$query = "DELETE FROM CONSSOLOL WHERE NRSEQUCONSOL = :P_NRSEQUCONSOL";
		try {
            $std = $this->connection->prepare($query);
            $std->execute($param);
        } catch (Exception $e){
            throw $e;
        }
    }
    
    public function deleteVeriConsol($row){
    	$param = array();
        $param['P_NRSEQUCONSOL'] = $row[0]['NRSEQUCONSOL'];
    	$query = "DELETE FROM VERIFCONSSOLOL WHERE NRSEQUCONSOL = :P_NRSEQUCONSOL";
		try {
            $std = $this->connection->prepare($query);
            $std->execute($param);
        } catch (Exception $e){
            throw $e;
        }
    }
    
    public function criaFiltroProdNeceComp($row){
        $filter = array(
		    array(
    		    "columnName" => "P_CDFILIAL", 
    		    "value" => $row['CDFILSOLI'],
    		    "operator" => "="
		    ),
	        array(
    		    "columnName" => "P_CDPRODUTO", 
    		    "value" => $row['CDPRODUTO'],
    		    "operator" => "="
    		),
    		array(
    		    "columnName" => "NRORG", 
    		    "value" => $row['NRORG'],
    		    "operator" => "="
    		)
    	);
    	return $filter;
    }
    
    public function criaFiltroProdConsOL($row){
        $filter = array(
		    array(
		        "columnName" => "P_NRSEQUCONSOL", 
		        "value" => $row['NRSEQUCONSOL'],
		        "operator" => "="
		    ),
	        array(
    		    "columnName" => "P_CDPRODUTO", 
    		    "value" => $row['CDPRODUTO'],
    		    "operator" => "="
    		),
		    array(
    		    "columnName" => "P_DTINCLUSAO", 
    		    "value" => $row['DTINCLUSAO'],
    		    "operator" => "="
		    ),
		    array(
    		    "columnName" => "P_CDFILSOLI", 
    		    "value" => $row['CDFILSOLI'],
    		    "operator" => "="
		    ),
		    array(
    		    "columnName" => "P_CDPRODINI", 
    		    "value" => $row['CDPRODINI'],
    		    "operator" => "="
		    ),
		    array(
    		    "columnName" => "P_CDPRODFIN", 
    		    "value" => $row['CDPRODFIN'],
    		    "operator" => "="
		    ),
    		array(
    		    "columnName" => "NRORG", 
    		    "value" => $row['NRORG'],
    		    "operator" => "="
    		)
    	);
    	return $filter;
    }
    
    public function criaFiltroEstoque($row){
		$filter = array(
		    array(
		        "columnName" => "P_NRSEQUCONSOL", 
		        "value" => $row['NRSEQUCONSOL'],
		        "operator" => "="
		    ),
		    array(
    		    "columnName" => "P_CDFILSOLI", 
    		    "value" => $row['CDFILSOLI'],
    		    "operator" => "="
		    ),
		    array(
    		    "columnName" => "P_CDFILLAN", 
    		    "value" => $row['CDFILLAN'],
    		    "operator" => "="
	        ),
	        array(
    		    "columnName" => "P_CDPRODUTO", 
    		    "value" => $row['CDPRODUTO'],
    		    "operator" => "="
    		)
    	);
    	return $filter;
    }
    
    public function insertJustificativa($row, $justificativa){
        $params = array(
            "P_NRSEQUCONSOL" => $row['NRSEQUCONSOL'],
            "P_CDPRODUTO"    => $row['CDPRODUTO'],
    		"P_QTANTESTUTIL" => $row['QTANTESTUTIL'],
            "P_DTENTJUSTCON" => null,
    		"P_QTDEPESTUTIL" => $row['QTESTUTILCONSOL'],
    		"P_DTJUSTCONSOL" => date('d/m/y'),
    		"P_DSJUSTCONSOL" => $justificativa,
    		"P_CDOPERADOR" => $this->environment->getCdoperador(),
    		"NRORG" => $this->environment->getNrorg()
    	);
    	$query = "INSERT INTO JUSTCONSSOLOL (NRSEQUCONSOL, CDPRODUTO, DTENTJUSTCON, CDOPERADOR, QTANTESTUTIL, QTDEPESTUTIL,  DTJUSTCONSOL, DSJUSTCONSOL, NRORG) VALUES (:P_NRSEQUCONSOL, :P_CDPRODUTO, :P_DTENTJUSTCON, :P_CDOPERADOR, :P_QTANTESTUTIL, :P_QTDEPESTUTIL, :P_DTJUSTCONSOL, :P_DSJUSTCONSOL, :NRORG)";
		try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e){
            throw $e;
        }
    }
    
    public function setEntrega($entrega, $newEstUtil, $prodnec){
        $newEntrega = array();
        foreach ($entrega as $rowEntrega){
            
            $rowEntrega['IDENTREGAVIAOL_OLD'] = $rowEntrega['IDENTREGAVIAOL'];
            $rowEntrega['QTDACOMPRAR_OLD'] = $rowEntrega['QTDACOMPRAR'];
            
            if(sizeof($prodnec) > 0){
                $rowEntrega['QTDACOMPRAR'] = $rowEntrega['QTENTRCONSOL'];
                $rowEntrega['IDENTREGAVIAOL'] = 'S';   
            } else {
                if($newEstUtil > 0){
                    $newEstUtil = $newEstUtil - $rowEntrega['QTENTRCONSOL'];
                    if($newEstUtil < 0){
                        $rowEntrega['QTDACOMPRAR'] = abs($newEstUtil);
                        $rowEntrega['IDENTREGAVIAOL'] = 'S';
                    } else {
                        $rowEntrega['QTDACOMPRAR'] = 0;
                        $rowEntrega['IDENTREGAVIAOL'] = 'N';
                    }
                } else {
                    if(($newEstUtil - $rowEntrega['QTENTRCONSOL']) < 0){
                        if($newEstUtil > 0){
                            $rowEntrega['QTDACOMPRAR'] = $rowEntrega['QTENTRCONSOL'] - $newEstUtil;    
                        } else {
                            $rowEntrega['QTDACOMPRAR'] = $rowEntrega['QTENTRCONSOL'];
                        }
                        $newEstUtil = 0;
                        $rowEntrega['IDENTREGAVIAOL'] = 'S';
                    }
                }
                array_push($newEntrega, $rowEntrega);
            }
        }
        return $newEntrega;
    }
    
    public function setEstoque($estoque, $rowProduto){
        $newEstoque = array();
        foreach ($estoque as $rowEstoque) {
            if($rowProduto['CDPRODESTO'] == $rowEstoque['CDPRODARVOL']){
                if($rowEstoque['IDUTESTCONSOL'] == 'N'){
                    if($rowProduto['QTESTUTILCONSOL'] >= ($rowEstoque['QTORIGPRODOL']/$rowProduto['VRFATOCONV'])){
                        $rowProduto['QTESTUTILCONSOL'] = ($rowProduto['QTESTUTILCONSOL'] - ($rowEstoque['QTORIGPRODOL']/$rowProduto['VRFATOCONV']));
                    } else {
                        if($rowProduto['QTESTUTILCONSOL'] > 0){
                            $rowProduto['QTESTUTILCONSOL'] = 0;
                        }
                    }
                    $rowEstoque['QTESTOPRODOL'] = $rowEstoque['QTORIGPRODOL'];
                } else {
                    if ($rowEstoque['IDUTESTCONSOL'] == 'S'){
                        $rowProduto['QTESTUTILCONSOL'] = $rowProduto['QTESTUTILCONSOL'] + ($rowEstoque['QTORIGPRODOL']/$rowProduto['VRFATOCONV']);
                    }
                    $rowEstoque['QTESTOPRODOL'] = 0;
                }       
            } else {
                if($rowEstoque['IDUTESTCONSOL'] == 'N'){
                    if($rowProduto['QTESTUTILCONSOL'] >= $rowEstoque['QTORIGPRODOL']){
                        $rowProduto['QTESTUTILCONSOL'] = ($rowProduto['QTESTUTILCONSOL'] - $rowEstoque['QTORIGPRODOL']);
                    } else {
                        if($rowProduto['QTESTUTILCONSOL'] > 0){
                            $rowProduto['QTESTUTILCONSOL'] = 0;
                        }
                    }
                    $rowEstoque['QTESTOPRODOL'] = $rowEstoque['QTORIGPRODOL'];   
                } else {
                    if ($rowEstoque['IDUTESTCONSOL'] == 'S'){
                        $rowProduto['QTESTUTILCONSOL'] = $rowEstoque['QTORIGPRODOL'];
                    }
                    $rowEstoque['QTESTOPRODOL'] = 0;
                } 
            }
            array_push($newEstoque, $rowEstoque);
        }
        $resposta[0] = $newEstoque;
        $resposta[1] = $rowProduto['QTESTUTILCONSOL'];
        
        return $resposta;
    }
    
    public function updateIdEntregaviaOL($row){
		$params = array(
    		"P_IDENTREGAVIAOL" => $row['IDENTREGAVIAOL'],
    		"P_NRSEQUCONSOL" => $row['NRSEQUCONSOL'],
    		"P_CDFILSOLI" => $row['CDFILSOLI'],
    		"P_CDFILLAN" => $row['CDFILLAN'],
    		"P_CDPRODUTO" => $row['CDPRODUTO'],
    		"P_DTENTRCONSOL" => $row['DTENTRCONSOL'],
    		"NRORG" => $this->environment->getNrorg()
    	);
        $query = "UPDATE ITEMCONSSOLOL SET IDENTREGAVIAOL = :P_IDENTREGAVIAOL WHERE NRSEQUCONSOL = :P_NRSEQUCONSOL AND CDFILSOLI = :P_CDFILSOLI AND CDFILLAN = :P_CDFILLAN AND CDPRODUTO = :P_CDPRODUTO AND DTENTRCONSOL = :P_DTENTRCONSOL AND NRORG = :NRORG";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e){
            throw $e;
        }
    }
    
    public function procedureGeraSolicitacaoOL($row){
        $procedure = new StoredProcedure($this->connection, 'GERA_SOLICITA_OL');
        $procedure->addParam(new Param('P_CDFILIOPELOG', Param::PARAM_INPUT, $row['CDFILSOLI'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRSEQUCONSOL', Param::PARAM_INPUT, $row['NRSEQUCONSOL'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDFILLANC', Param::PARAM_INPUT, $row['CDFILLAN'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDOPERLANC', Param::PARAM_INPUT, $this->environment->getCdoperador(), Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_ROWSAFFECT', Param::PARAM_OUTPUT, null, Param::PARAM_TYPE_STR, 10));
        return $procedure->execute();
    }
    
    public function procedureNecessidadeOL($row){
        $procedure = new StoredProcedure($this->connection, 'NECESSIDADE_OL');
        $procedure->addParam(new Param('P_CDFILIAL', Param::PARAM_INPUT, $row['CDFILIAL'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTINICIAL', Param::PARAM_INPUT, $row['DTINICIAL'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTFINAL', Param::PARAM_INPUT, $row['DTFINAL'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDPRODINI', Param::PARAM_INPUT, $row['CDPRODUTO'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDPRODFIN', Param::PARAM_INPUT, $row['CDPRODUTO'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_PEACRESCIMO', Param::PARAM_INPUT, 0, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDOPERADOR', Param::PARAM_INPUT, null, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRSEQUCONSOL', Param::PARAM_INPUT, $row['NRSEQUCONSOL'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDFILLANC', Param::PARAM_INPUT, $row['CDFILLAN'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_PRIORIZAREST', Param::PARAM_INPUT, $row['IDEMBESTCONSOL'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_PREVISAOCONSUMO', Param::PARAM_INPUT, $row['IDCONSPREVCONOL'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_GERASOLOPERLOG', Param::PARAM_INPUT, 'N', Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDGRUPPROD', Param::PARAM_INPUT, null, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDSUBGRUPO', Param::PARAM_INPUT, null, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDGRUPFILI', Param::PARAM_INPUT, null, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_ROWSAFFECT', Param::PARAM_OUTPUT, null, Param::PARAM_TYPE_STR, 11));
        return $procedure->execute();
    }
}